/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.io.IOException;
import java.io.OutputStream;


/**
 * This exception is thrown when a client-side error occurres.
 */
public class ClientException extends RuntimeException {

    /**
     * Connection excpetion.
     */
    public static final String CONNECTION_FAILED = "CONNECTION_FAILED";

    /**
     * Unexpected MIME type.
     */
    public static final String UNEXPECTED_MIME_TYPE = "UNEXPECTED_MIME_TYPE";

    private String m_code = null;

    /**
     * Constructs an exception without a message.
     */
    public ClientException() {
        super();
    }

    /**
     * Constructs an exception with a detailed message.
     * 
     * @param message
     *            The message associated with the exception.
     */
    public ClientException(final String message) {
        super(message);
    }

    public ClientException(final String message, final String code) {
        super(message);
        this.m_code = code;
    }

    public ClientException(final String message, final Exception cause) {
        super(message, cause);
    }

    public ClientException(final String message, final Exception cause, final String code) {
        super(message, cause);
        this.m_code = code;
    }

    /**
     * writes a client exception XML document according to the specified
     * OutputStream.
     */
    public void write(final OutputStream out) throws IOException {

        out.write(getAsXML().getBytes());
        out.flush();
    }

    public String getAsXML() {
        StringBuffer buf = new StringBuffer();
        buf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
        buf.append("<WebSecurityClient-ExceptionReport>\n");
        buf.append("<ClientException>\n");
        buf.append("<ExceptionMessage>\n");
        buf.append(getMessage());
        buf.append("</ExceptionMessage>\n");

        if (getCause() != null) {
            buf.append("<ExceptionCause>\n");
            buf.append(getCause());
            buf.append("</ExceptionCause>\n");
        }
        buf.append("</ClientException>\n");
        buf.append("</WebSecurityClient-ExceptionReport>\n");
        return buf.toString();
    }

    public Transferable getAsTransferable() {
        return TransferableFactory.getInstance().createTextualTransferable("text/xml", getAsXML(), "UTF-8");
    }

    public String getCode() {
        return m_code;
    }
}