/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/


package org.n52.security.common.artifact;


/**
 * HttpHeaderAttribute represents simple Http Header Field as a Key-Value Pair of Strings.
 *
 * @author reiprecht
 */
public class HttpHeaderAttribute implements TransferAttribute{

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HttpHeaderAttribute.class);

    public static final String HEADER_NAME_CONTENTTYPE = "Content-Type";
    /**
     * Holds values like 'gzip' (this is the real "Content-Encoding"
     */
    public static final String HEADER_NAME_CONTENT_ENCODING = "Content-Encoding";

    public static final String HEADER_NAME_CONTENTCHARSET = "Content-Charset";

    public static final String HEADER_NAME_REFERER = "Referer";

    public static final String HEADER_NAME_COOKIE = "Cookie";

    public static final String HEADER_NAME_XFORWARDEDFOR = "X-Forwarded-For";

    /**
     * Name of the HTTP header.
     */
    protected String m_name;

    /**
     * String value HTTP header.
     */
    protected String m_value;

    private HttpHeaderAttribute(String pName, String pValue) {
        m_name = pName;
        m_value = pValue;
    }

    public static HttpHeaderAttribute createHttpHeaderAttribute(String pName,String pValue){
        return new HttpHeaderAttribute(pName,pValue);
    }


    public String getName() {
        return m_name;
    }

    public Object getValue() {
        return m_value;
    }

    public String toString() {
        return m_name + ": " + m_value;
    }

}