/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.crypto;

import java.math.BigInteger;
import java.security.cert.Certificate;

/**
 * Simple base class for decorator implementations of KeyPairProviders.
 * 
 * @author Marko Reiprecht
 */
public abstract class AbstractKeyPairProviderDecorator implements KeyPairProvider {

    private KeyPairProvider m_delegate;

    /**
     * Creates new instance.
     */
    public AbstractKeyPairProviderDecorator() {
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AbstractKeyPairProviderDecorator(final KeyPairProvider delegate) {
        m_delegate = delegate;
    }

    /**
     * @return the delegate
     */
    public KeyPairProvider getDelegate() {
        return m_delegate;
    }

    /**
     * @param delegate
     *            the delegate to set
     */
    public void setDelegate(final KeyPairProvider delegate) {
        if (delegate == null) {
            throw new IllegalArgumentException("delegate must not null");
        }
        m_delegate = delegate;
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveByAlias(java.lang.String, char[])
     */
    public KeyPair resolveByAlias(final String alias, final char[] password) throws KeyPairResolvingException {
        return getDelegate().resolveByAlias(alias, password);
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveByCertificate(java.security.cert.Certificate, char[])
     */
    public KeyPair resolveByCertificate(final Certificate cert, final char[] password) throws KeyPairResolvingException {
        return getDelegate().resolveByCertificate(cert, password);
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveBySerialIssuer(java.lang.String, java.math.BigInteger,
     *      char[])
     */
    public KeyPair resolveBySerialIssuer(final String issuerDN, final BigInteger serial, char[] password)
            throws KeyPairResolvingException {
        return getDelegate().resolveBySerialIssuer(issuerDN, serial, password);
    }

}
