/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.crypto;

import java.io.Serializable;
import java.security.Key;
import java.security.PublicKey;
import java.security.cert.Certificate;

/**
 * Class DefaultKeyPair is a bean (vo) style implementation of a KeyPair and can be used by different KeyPairProviders.
 * 
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public class DefaultKeyPair implements KeyPair, Serializable {

    // ------------------------------ FIELDS ------------------------------

    private static final long serialVersionUID = 1051108545784644231L;
    private Key m_privateKey;
    private Certificate m_certificate;
    private String m_alias;
    private Certificate[] m_certificateChain;

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * @see KeyPair#getAlias()
     */
    public String getAlias() {
        return m_alias;
    }

    /**
     * Method sets the alias.
     * 
     * @param alias
     *            the alias.
     */
    public void setAlias(final String alias) {
        m_alias = alias;
    }

    /**
     * @see KeyPair#getCertificate()
     */
    public Certificate getCertificate() {
        return m_certificate;
    }

    /**
     * Method sets the certificate.
     * 
     * @param certificate
     *            the certificate.
     */
    public void setCertificate(final Certificate certificate) {
        m_certificate = certificate;
    }

    /**
     * @see KeyPair#getCertificateChain()
     */
    public Certificate[] getCertificateChain() {
        return m_certificateChain;
    }

    /**
     * Method sets the certificateChain.
     * 
     * @param certificateChain
     *            the certificateChain.
     */
    public void setCertificateChain(final Certificate[] certificateChain) {
        m_certificateChain = certificateChain;
    }

    /**
     * @see KeyPair#getPrivateKey()
     */
    public Key getPrivateKey() {
        return m_privateKey;
    }

    /**
     * Method sets the key.
     * 
     * @param privateKey
     *            the key.
     */
    public void setPrivateKey(final Key privateKey) {
        m_privateKey = privateKey;
    }

    /**
     * @see KeyPair#getPublicKey()
     */
    public PublicKey getPublicKey() {
        if (isPublicKeySet()) {
            return m_certificate.getPublicKey();
        }
        return null;
    }

    /**
     * @see KeyPair#isCertificateChainSet()
     */
    public boolean isCertificateChainSet() {
        return m_certificateChain != null && m_certificateChain.length > 0;
    }

    /**
     * @see KeyPair#isCertificateSet()
     */
    public boolean isCertificateSet() {
        return m_certificate != null;
    }

    /**
     * @see KeyPair#isPrivateKeySet()
     */
    public boolean isPrivateKeySet() {
        return m_privateKey != null;
    }

    /**
     * @see KeyPair#isPublicKeySet()
     */
    public boolean isPublicKeySet() {
        return isCertificateSet();
    }
}
