/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 30.05.2008
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import org.w3c.dom.Node;
import org.w3c.dom.traversal.NodeFilter;

/**
 * A DocumentVisitor encapsulates pices of code processed during visiting a dom tree.
 * <p/>
 * This visitors typical used by clients in conjunction with the DocumentTraverser.
 * <p/>
 * See Visitor-Pattern for details about the common usage of visitors.
 * <p/>
 * If you can express document changes in visitors, instead of xpath expressions use visitors,
 * because they are much faster, because they traverse a document only once.
 * <p/>
 * The pre/post methods are only called by the DocumentTraverser in the depth first traversal.
 *
 * @author Marko Reiprecht
 *         Created on 30.05.2008
 * @version $Revision: $
 */
public interface DocumentVisitor extends NodeFilter {

    /**
     * Method visits a node.
     * It is called directly after the preVisit method in depth first traversals
     * and the only method called in breadth first traversals.
     *
     * @param node the node.
     */
    void visit(Node node);

    /**
     * Method pre visits a node.
     * It is called if the DocumentTraverser first time visits the node.
     * Only invoked in depth first traversals.
     *
     * @param node the node.
     */
    void preVisit(final Node node);

    /**
     * Method post visits a node.
     * It is called if the DocumentTraverser has all childs af the node visited.
     * Only invoked in depth first traversals.
     *
     * @param node the node.
     */
    void postVisit(final Node node);
}
