/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 24.03.2008
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import javax.xml.parsers.DocumentBuilder;

import org.w3c.dom.Document;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;

/**
 * Class PooledDOMParser is a DOMParser, which accquires it's DocumentBuilder from a DocumentBuilderPool.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 24.03.2008
 * @version $Revision: $
 */
class PoolingDOMParser extends DOMParser {

    // ------------------------------ FIELDS ------------------------------

    private DOMParserOptions m_domParserOptions;
    private DocumentBuilderPool m_documentBuilderPool;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     * <p/>
     * It's protected because you shall use the {@link DOMParser#createPoolingParser()} methods.
     *
     * @param domParserOptions    the domParserOptions.
     * @param documentBuilderPool the documentBuilderPool.
     */
    protected PoolingDOMParser(final DOMParserOptions domParserOptions,
                               final DocumentBuilderPool documentBuilderPool) {
        m_domParserOptions = domParserOptions;
        m_documentBuilderPool = documentBuilderPool;
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * @see DOMParser#parse(InputSource, ErrorHandler, EntityResolver)
     */
    public Document parse(final InputSource source,
                          final ErrorHandler errorhandler,
                          final EntityResolver entityResolver) throws DOMParserException {
        DocumentBuilder pooledDocumentBuilder = m_documentBuilderPool.acquire(m_domParserOptions);
        try {
            pooledDocumentBuilder.setEntityResolver(entityResolver);
            pooledDocumentBuilder.setErrorHandler(errorhandler);
            return pooledDocumentBuilder.parse(source);
        } catch (Exception ex) {
            throw new DOMParserException("unexpected exception during parsing", ex);
        } finally {
            m_documentBuilderPool.release(pooledDocumentBuilder, m_domParserOptions);
        }
    }
}
